@@ -1,3 +1,5 @@
+(require 'cl-lib)
+(require 'dom)
 (require 'esxml)
 (require 'esxml-query)
 (require 'ert)
@@ -269,54 +271,44 @@
 
 (ert-deftest esxml-query-test ()
   (let ((root esxml-query-document))
-    (should (eq (esxml-node-tag (esxml-query "*" root)) 'html))
-    (should (eq (esxml-node-tag (esxml-query "table" root)) 'table))
+    (should (eq (dom-tag (esxml-query "*" root)) 'html))
+    (should (eq (dom-tag (esxml-query "table" root)) 'table))
     (should-not (esxml-query "foo" root))
-    (should (eq (esxml-node-tag (esxml-query "table, foo" root)) 'table))
-    (should (eq (esxml-node-tag (esxml-query "foo, table" root)) 'table))
+    (should (eq (dom-tag (esxml-query "table, foo" root)) 'table))
+    (should (eq (dom-tag (esxml-query "foo, table" root)) 'table))
     (should-not (esxml-query "foo, bar" root))
-    (should (eq (esxml-node-tag (esxml-query "thead, tbody" root)) 'thead))
-    (should (eq (esxml-node-tag (esxml-query "tbody, thead" root)) 'thead))
+    (should (eq (dom-tag (esxml-query "thead, tbody" root)) 'thead))
+    (should (eq (dom-tag (esxml-query "tbody, thead" root)) 'thead))
 
     (should-not (esxml-query "table table" root))
-    (should (equal (esxml-node-children (esxml-query "table thead th" root))
-                   '("Key")))
-    (should (equal (esxml-node-children (esxml-query "table td" root))
-                   '("Foo")))
-    (should (equal (esxml-node-children (esxml-query "table * td" root))
-                   '("Foo")))
+    (should (equal (dom-children (esxml-query "table thead th" root)) '("Key")))
+    (should (equal (dom-children (esxml-query "table td" root)) '("Foo")))
+    (should (equal (dom-children (esxml-query "table * td" root)) '("Foo")))
     (should-not (esxml-query "td foo" root))
     (should-not (esxml-query "tr foo td" root))
-    (should (equal (esxml-node-children (esxml-query "tbody>tr>td" root))
-                   '("Foo")))
+    (should (equal (dom-children (esxml-query "tbody>tr>td" root)) '("Foo")))
     (should-not (esxml-query "tr>foo" root))
     (should-not (esxml-query "foo>td" root))
 
-    (should (equal (esxml-node-children (esxml-query "#heading>th" root))
-                   '("Key")))
-    (should (equal (esxml-node-tag (esxml-query "tr#heading" root)) 'tr))
-    (should (equal (esxml-node-tag (esxml-query "#heading" root)) 'tr))
+    (should (equal (dom-children (esxml-query "#heading>th" root)) '("Key")))
+    (should (equal (dom-tag (esxml-query "tr#heading" root)) 'tr))
+    (should (equal (dom-tag (esxml-query "#heading" root)) 'tr))
     (should-not (esxml-query "th#heading" root))
     (should-not (esxml-query "tr #heading" root))
 
-    (should (equal (esxml-node-children (esxml-query ".row>td" root))
-                   '("Foo")))
+    (should (equal (dom-children (esxml-query ".row>td" root)) '("Foo")))
     (should-not (esxml-query ".foo" root))
     (should (esxml-query ".row.even" root))
     (should-not (esxml-query ".row.foo" root))
-    (should (equal (esxml-node-children (esxml-query ".row .value" root))
-                   '("1")))
-    (should (equal (esxml-node-children (esxml-query ".row.odd .value" root))
-                   '("2")))
-    (should (equal (esxml-node-children (esxml-query ".even .value, .odd .value" root))
-                   '("1")))
+    (should (equal (dom-children (esxml-query ".row .value" root)) '("1")))
+    (should (equal (dom-children (esxml-query ".row.odd .value" root)) '("2")))
+    (should (equal (dom-children (esxml-query ".even .value, .odd .value" root)) '("1")))
 
-    (should (eq (esxml-node-tag (esxml-query "[rel=self]" root)) 'link))
+    (should (eq (dom-tag (esxml-query "[rel=self]" root)) 'link))
     (should-not (esxml-query "[rel=elf]" root))
     (should-not (esxml-query "[rel=sel]" root))
     (should-not (esxml-query "[rel=selfie]" root))
-    (should (equal (esxml-node-children (esxml-query "[class='row even'] td" root))
-                   '("Foo")))
+    (should (equal (dom-children (esxml-query "[class='row even'] td" root)) '("Foo")))
     (should (esxml-query "[class^=row]" root))
     (should (esxml-query "[class$=row]" root))
     (should-not (esxml-query "[class^=key]" root))
@@ -334,73 +326,65 @@
     (should (esxml-query "[class~=row]" root))
     (should (esxml-query "[class~=key]" root))
     (should-not (esxml-query "[class~=foo]" root))
-    (should (equal (esxml-node-children (esxml-query "[class~=row][class~=odd] [class~=value]" root))
+    (should (equal (dom-children (esxml-query "[class~=row][class~=odd] [class~=value]" root))
                    '("2")))
-    (should (equal (cdr (assq 'lang (esxml-node-attributes (esxml-query "[lang|=en]" root))))
-                   "en-US"))
+    (should (equal (dom-attr (esxml-query "[lang|=en]" root) 'lang) "en-US"))
     (should-not (esxml-query "[lang|=US]" root))))
 
 (ert-deftest esxml-query-all-test ()
   (let ((root esxml-query-document))
-    (should (equal (cl-remove-if 'not (mapcar 'esxml-node-tag
-                                              (esxml-query-all "*" root)))
-                   '(html head meta link title
-                          body table thead tr th th tbody tr td td tr td td)))
-    (should (equal (mapcar 'esxml-node-tag (esxml-query-all "table" root))
-                   '(table)))
+    (should (equal (mapcar 'dom-tag (cl-remove-if 'stringp (esxml-query-all "*" root)))
+                   '( html head meta link title
+                      body table thead tr th th tbody tr td td tr td td)))
+    (should (equal (mapcar 'dom-tag (esxml-query-all "table" root)) '(table)))
     (should-not (esxml-query-all "foo" root))
-    (should (equal (mapcar 'esxml-node-tag (esxml-query-all "table, foo" root))
-                   '(table)))
-    (should (equal (mapcar 'esxml-node-tag (esxml-query-all "foo, table" root))
-                   '(table)))
+    (should (equal (mapcar 'dom-tag (esxml-query-all "table, foo" root)) '(table)))
+    (should (equal (mapcar 'dom-tag (esxml-query-all "foo, table" root)) '(table)))
     (should-not (esxml-query-all "foo, bar" root))
-    (should (equal (mapcar 'esxml-node-tag (esxml-query-all "thead, tbody" root))
+    (should (equal (mapcar 'dom-tag (esxml-query-all "thead, tbody" root))
                    '(thead tbody)))
-    (should (equal (mapcar 'esxml-node-tag (esxml-query-all "tbody, thead" root))
+    (should (equal (mapcar 'dom-tag (esxml-query-all "tbody, thead" root))
                    '(thead tbody)))
 
     (should-not (esxml-query-all "table table" root))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all "table thead th" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all "table thead th" root)))
                    '("Key" "Value")))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all "table td" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all "table td" root)))
                    '("Foo" "1" "Bar" "2")))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all "table * td" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all "table * td" root)))
                    '("Foo" "1" "Bar" "2")))
     (should-not (esxml-query-all "td foo" root))
     (should-not (esxml-query-all "tr foo td" root))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all "tbody>tr>td" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all "tbody>tr>td" root)))
                    '("Foo" "1" "Bar" "2")))
     (should-not (esxml-query-all "tr>foo" root))
     (should-not (esxml-query-all "foo>td" root))
 
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all "#heading>th" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all "#heading>th" root)))
                    '("Key" "Value")))
-    (should (equal (mapcar 'esxml-node-tag (esxml-query-all "tr#heading" root))
-                   '(tr)))
-    (should (equal (mapcar 'esxml-node-tag (esxml-query-all "#heading" root))
-                   '(tr)))
+    (should (equal (mapcar 'dom-tag (esxml-query-all "tr#heading" root)) '(tr)))
+    (should (equal (mapcar 'dom-tag (esxml-query-all "#heading" root)) '(tr)))
     (should-not (esxml-query-all "th#heading" root))
     (should-not (esxml-query-all "tr #heading" root))
 
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all ".row>td" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all ".row>td" root)))
                    '("Foo" "1" "Bar" "2")))
     (should-not (esxml-query-all ".foo" root))
     (should (= (length (esxml-query-all ".row.even" root)) 1))
     (should-not (esxml-query-all ".row.foo" root))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all ".row .value" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all ".row .value" root)))
                    '("1" "2")))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all ".row.odd .value" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all ".row.odd .value" root)))
                    '("2")))
     (should (= (length (esxml-query-all ".even, .odd" root)) 2))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all ".even .value, .odd .value" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all ".even .value, .odd .value" root)))
                    '("1" "2")))
 
-    (should (eq (esxml-node-tag (car (esxml-query-all "[rel=self]" root)))
-                'link))
+    (should (eq (dom-tag (car (esxml-query-all "[rel=self]" root))) 'link))
     (should-not (esxml-query-all "[rel=elf]" root))
     (should-not (esxml-query-all "[rel=sel]" root))
     (should-not (esxml-query-all "[rel=selfie]" root))
-    (should (equal (mapcar 'car (mapcar 'esxml-node-children (esxml-query-all "[class='row even'] td" root)))
+    (should (equal (mapcar 'car (mapcar 'dom-children (esxml-query-all "[class='row even'] td" root)))
                    '("Foo" "1")))
     (should (= (length (esxml-query-all "[class^=row]" root)) 3))
     (should (= (length (esxml-query-all "[class$=row]" root)) 1))
@@ -419,8 +403,7 @@
     (should (= (length (esxml-query-all "[class~=row]" root)) 3))
     (should (= (length (esxml-query-all "[class~=key]" root)) 2))
     (should-not (esxml-query-all "[class~=foo]" root))
-    (should (equal (car (esxml-node-children (car (esxml-query-all "[class~=row][class~=odd] [class~=value]" root))))
+    (should (equal (car (dom-children (car (esxml-query-all "[class~=row][class~=odd] [class~=value]" root))))
                    "2"))
-    (should (equal (cdr (assq 'lang (esxml-node-attributes (car (esxml-query-all "[lang|=en]" root)))))
-                   "en-US"))
+    (should (equal (dom-attr (car (esxml-query-all "[lang|=en]" root)) 'lang) "en-US"))
     (should-not (esxml-query-all "[lang|=US]" root))))
